#
# spec file for package wget
#
# Copyright (c) 2018 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           wget
Version:        1.14
Release:        15.1
Summary:        A Tool for Mirroring FTP and HTTP Servers
License:        GPL-3.0+
Group:          Productivity/Networking/Web/Utilities
Url:            http://www.gnu.org/software/wget/
Source:         http://ftp.gnu.org/gnu/wget/%name-%version.tar.xz
Patch0:         wgetrc.patch
# PATCH-FEATURE-UPSTREAM wget-libproxy.patch dimstar@opensuse.org -- Add libproxy support to wget
Patch1:         wget-libproxy.patch
Patch5:         wget-1.14-openssl-no-intern.patch
Patch6:         wget-1.14-no-ssl-comp.patch
# PATCH-FIX-OPENSUSE fix pod syntax for perl 5.18 coolo@suse.de
Patch7:         wget-fix-pod-syntax.diff
Patch8:         wget-CVE-2014-4877.patch
Patch9:         wget-CVE-2016-4971.patch
Patch10:        wget-CVE-2015-2059.patch
Patch11:        wget-basicauth.patch
Patch12:        wget-CVE-2016-7098.patch
Patch13:        wget-dont-free-dcgettext.patch
Patch14:        wget-enforce-tls12.patch
Patch15:        wget-CVE-2017-6508.patch
Patch16:        wget-stack-overflow-on-negative-chunksize-CVE-2017-13089.patch
Patch17:        wget-stack-overflow-on-negative-chunksize-CVE-2017-13090.patch
Patch18:        wget-cookie-injection-CVE-2018-0494.patch
BuildRequires:  libpng-devel
%if 0%{suse_version} > 1110
BuildRequires:  libproxy-devel
%endif
BuildRequires:  automake
BuildRequires:  libidn-devel
BuildRequires:  makeinfo
BuildRequires:  openssl-devel
BuildRequires:  pkg-config
BuildRequires:  xz
PreReq:         %install_info_prereq
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Wget enables you to retrieve WWW documents or FTP files from a server.
This can be done in script files or via the command line.

%prep
%setup -q
%patch0
%if 0%{suse_version} > 1110
%patch1
%endif
%patch5
%patch6
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1

%build
%if 0%{suse_version} > 1110
# only wget-libproxy.patch needs this
autoreconf --force
%endif
%configure --with-ssl=openssl
make %{?_smp_mflags}

%install
%makeinstall
%find_lang %{name}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files -f %{name}.lang
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS README MAILING-LIST
%doc doc/sample.wgetrc util/rmold.pl
%{_mandir}/*/wget*
%{_infodir}/wget*
%config(noreplace) %{_sysconfdir}/wgetrc
%{_bindir}/*

%changelog
* Mon May 14 2018 josef.moellers@suse.com
- Fixed Cookie injection vulnerability by checking for
  and joining continuiation lines.
  [bsc#1092061,wget-cookie-injection-CVE-2018-0494.patch,
  CVE-2018-0494]
* Tue Oct 24 2017 josef.moellers@suse.com
- Fixed two stack overflow vulnerabilities if a chunksize is
  negative.
  [bsc#1064715,wget-stack-overflow-on-negative-chunksize-CVE-2017-13089.patch,
  bsc#1064716,wget-stack-overflow-on-negative-chunksize-CVE-2017-13090.patch,
  CVE-2017-13089,CVE-2017-13090]
* Wed Mar  8 2017 josef.moellers@suse.com
- src/url.c (url_parse): Reject control characters in host part
  of URL
  (CVE-2017-6508, wget-CVE-2017-6508.patch, bsc#1028301)
* Wed Dec  7 2016 josef.moellers@suse.com
- Added support for TLSv1.1 and TLSv1.2.
  (bsc#1012677, wget-enforce-tls12.patch)
* Thu Oct 20 2016 josef.moellers@suse.com
- Don't call xfree() on string returned by usr_error()!
  (bsc#1005091, wget-dont-free-dcgettext.patch)
* Wed Aug 31 2016 josef.moellers@suse.com
- Fixed a potential race condition by creating files with .tmp ext
  and making them accessible to the current user only.
  (bsc#995964, CVE-2016-7098, wget-CVE-2016-7098.patch)
* Wed Jul 27 2016 josef.moellers@suse.com
- Fix for HTTP to a FTP redirection file name confusion vulnerability
  (bnc#984060, CVE-2016-4971, wget-CVE-2016-4971.patch).
  - Work around a libidn <= 1.30 vulnerability
  (bsc#937096, CVE-2015-2059, wget-CVE-2015-2059.patch).
  - Fix for wget fails with basicauth: Failed writing HTTP request:
  Bad file descriptor
  (bnc#958342, wget-basicauth.patch)
* Mon Nov  3 2014 max@suse.com
- Fix for FTP symlink arbitrary filesystem access
  (bnc#902709, CVE-2014-4877, wget-CVE-2014-4877.patch).
* Thu Jun 20 2013 coolo@suse.com
- add wget-fix-pod-syntax.diff to fix build with perl 5.18
* Thu May  2 2013 p.drouand@gmail.com
- Update to version 1.14
  + add support for content-on-error.  It allows to store the HTTP
    payload on 4xx or 5xx errors.
  + add support for WARC files.
  + fix a memory leak problem in the GNU TLS backend.
  + autoreconf works again for distributed tarballs.
  + print some diagnostic messages to stderr not to stdout.
  + report stdout close errors.
  + accept the --report-speed option.
  + enable client certificates when GNU TLS is used.
  + add support for TLS Server Name Indication.
  + accept the arguments --accept-reject and --reject-regex.
  + the GNU TLS backend honors correctly the timeout value.
  + add support for RFC 2617 Digest Access Authentication.
- Drop patchs obsoleted by upstream
  + wget-sni.patch
  + wget-stdio.h.patch
- Rebase patchs to work with upstream
  + wget-openssl-no-intern.patch > wget-1.14-openssl-no-intern.patch
  + wget-no-ssl-comp.patch > wget-1.14-no-ssl-comp.patch
* Thu May  2 2013 seife+obs@b1-systems.com
- add makeinfo BuildRequires to fix build
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Mon Nov 12 2012 crrodriguez@opensuse.org
- wget-no-ssl-comp.patch: Since the apperance of the "CRIME attack"
  (CVE-2012-4929) HTTPS clients must not negotatiate ssl compression.
* Thu Sep 27 2012 crrodriguez@opensuse.org
- Add wget-openssl-no-intern.patch to Build with OPENSSL_NO_SSL_INTERN,
  which is openssl's poor man's version of visibility, to avoid breaking
  applications ABI on library internal changes.
* Fri Jul 27 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Wed Mar 21 2012 dimstar@opensuse.org
- Adjust wget-libproxy.patch: give debug output only when
  opt.debug is set to non-zero values, so when -d is specified.
  Fix bnc#753242.
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Oct 19 2011 max@suse.com
- New version: 1.13.4:
  * Now --timestamping and --continue work well together.
  * Return a network failure when FTP downloads fail and
  - -timestamping is specified.
  * Support HTTP/1.1
  * Fix some portability issues.
  * Handle properly malformed status line in a HTTP response.
  * Ignore zero length domains in $no_proxy.
  * Exit with failure if -k is specified and -O is not a regular
    file.
  * Cope better with unclosed html tags.
  * Print diagnostic messages to stderr, not stdout.
  * Do not use an additional HEAD request when
  - -content-disposition is used, but use directly GET.
  * Report the average transfer speed correctly when multiple
    URLs are specified and -c influences the transferred data
    amount.
  * By default, on server redirects, use the original URL to get
    the local file name. Close CVE-2010-2252.  This introduces a
    backward-incompatibility; any script that relies on the old
    behaviour must use --trust-server-names.
  * Fix a problem when -k is used and some URLs are specified
    trough CSS.
  * Convert correctly URLs that need to be encoded to local files
    when following links.
  * Use persistent connections with proxies supporting them.
  * Print the total download time as part of the summary for
    recursive downloads.
  * Now it is possible to specify a different startup
    configuration file trough the --config option.
  * Fix an infinite loop with the error '<filename> has sprung
    into existence' on a network error and -nc is used.
  * Now --adjust-extension does not modify the file extension if
    the file ends in .htm.
  * Support HTTP/1.1 307 redirects keep request method.
  * Now --no-parent doesn't fetch undesired files if HTTP and
    HTTPS are used by the same host on different pages.
  * Do not attempt to remove the file if it is not in the accept
    rules but it is the output destination file.
  * Introduce `show_all_dns_entries' to print all IP addresses
    corresponding to a DNS name when it is resolved.
- Adjuct patches to the new version.
- wget-1.12-nosslv2.patch got included upstream.
* Sat Oct 15 2011 crrodriguez@opensuse.org
- fix typo in sni patch , in the IPV6 case should be
  is_valid_ipv6_address() instead of is_valid_ipv4_address()
- Add comment to the patch referencing upstream tracker.
* Fri Oct 14 2011 crrodriguez@opensuse.org
-  Update nosslv2 patch with the version in upstream
-  Wget now supports SNI (server name indication), patch
  based on a 2 year old fix submitted to upstream list
  that somehow fell through the cracks.
* Sat Apr  9 2011 crrodriguez@opensuse.org
- SSLv2 is being disabled in openSSL, allow painless obsoletion.
- Support IDN.
* Sun Aug 15 2010 dimstar@opensuse.org
- Update to version 1.12:
  + SECURITY FIX: It had been possible to trick Wget into accepting
    SSL certificates that don't match the host name, through the
    trick of embedding NUL characters into the certs' common name
  + Added support for CSS. This includes:
  - Parsing links from CSS files, and from CSS content found in
    HTML style tags and attributes.
  - Supporting conversion of links found within CSS content, when
  - -convert-links is specified.
  - Ensuring that CSS files end in the ".css" filename extension,
    when --convert-links is specified.
  + Added support for Internationalized Resource Identifiers
  + Wget now provides more sensible exit status codes when
    downloads don't proceed as expected
  + --default-page option (and associated wgetrc command) added to
    support alternative default names for index.html.
  + --ask-password option (and associated wgetrc command) added to
    support password prompts at the console.
  + The --input-file option now also handles retrieving links from
    an external file.
  + The output generated by the --version option now includes
    information on how it was built, and the set of configure-time
    options that were selected.
  + --html-extension has been renamed to --adjust-extension, to
    reflect the fact that it now also applies to CSS content
  + An "ascii" specifier is now accepted by --restrict-file-names,
    which forces the percent-encoding of all non-ASCII bytes
  + Several previously existing, but undocumented .wgetrc options
    are now documented.
- Drop upstream fixed wget-nullcerts.patch.
- Minor spec-cleanups using spec-cleaner
- Use smp_mflags
- Add libproxy-devel BuildRequires and enable libproxy support
  using wget-libproxy.patch.
- Add pkg-config BuildRequire to succeed with the bootstrap on
  openSUSE < 11.3.
* Wed Dec 16 2009 jengelh@medozas.de
- Enable parallel building
* Tue Aug 11 2009 max@suse.de
- Fix vulnerability against SSL certificates with a zero byte in
  the common name field (wget-nullcerts.patch, bnc#528298).
* Mon Sep  1 2008 max@suse.de
- New version 1.11.4:
  * Fixed a problem in authenticating over HTTPS through a proxy.
    (Regression in 1.11 over 1.10.2.)
  * The combination of -r or -p with -O, which was disallowed in 1.11,
    has been downgraded to a warning in 1.11.2.
  * Further improvements to progress bar displays in non-English
    locales (too many spaces could be inserted, causing the display to
    scroll).
  * Successive invocations of Wget on FTP URLS, with
  - -no-remove-listing and --continue, was causing Wget to append,
    rather than replace, information in the .listing file, and thereby
    download the same files multiple times. Fixed in 1.11.2.
  * Wget 1.11 no longer allowed ".." to persist at the beginning of
    URLs, for improved conformance with RFC 3986. However, this
    behavior presents problems for some FTP setups, and so they are now
    preserved again, for FTP URLs only.
  * Downgraded -N with -O to a warning, rather than an error.
  * Fixed a crash on some systems, due to Wget casting a
    pointer-to-long to a pointer-to-time_t.
  * Fixed an issue (apparently a regression) where -O would refuse to
    download when -nc was given, even though the file didn't exist.
  * Fixed a situation where Wget could abort with --continue if the
    remote server gives a content-length of zero when the file exists
    locally with content.
* Wed Apr 30 2008 max@suse.de
- Let the resolver (/etc/gai.conf) decide whether to prefer IPv4
  or IPv6 if a host has addresses of both kinds (bnc#310224).
- Passive FTP is the default now, so we don't need to set it
  explicitly anymore.
* Wed Apr 23 2008 max@suse.de
- New version 1.11.1:
  * Migration to the GPLv3+ license.
  * Improvements to the HTTP password authentication code, bringing
    it a little closer to RFC compliance (more is needed).
  * Basic support for respecting filenames specified via
    `Content-Disposition' headers (turned on with --content-disposition,
    but please read the documentation).
  * An --ignore-case option to make wildcard- and suffix-matching
    case-sensitive.
  * Progress bar now displays correctly in non-English locales (and a
    related assertion failure was fixed).
  * Added option --auth-no-challenge, to support broken pre-1.11
    authentication-before-server-challenge, which turns out to still
    be useful for some limited cases.
  * Documentation of accept/reject lists in the manual's "Types of
    Files" section now explains various aspects of their behavior that
    may be surprising, and notes that they may change in the future.
  * Documentation of --no-parents now explains how a trailing slash,
    or lack thereof, in the specified URL, will affect behavior.
- Purged lots of obsolete patches and cleaned up the spec file.
* Sun Feb 24 2008 crrodriguez@suse.de
- make use of find_lang macro
* Wed Mar 28 2007 max@suse.de
- Fixes a null pointer dereference (#231063, CVE-2006-6719)
* Thu Jun 22 2006 max@suse.de
- Removed the unneeded fix for CAN-2004-1487
  (bugs #179369 and #185214).
- Filter escape responses from the HTTP server (CAN-2004-1488,
  bug #185265).
* Wed Feb  1 2006 max@suse.de
- Fixed (hacked) restart of interrupted FTP transactions (#144410).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 mmj@suse.de
- Compile with -fstack-protector
* Fri Oct 14 2005 mmj@suse.de
- Update to wget 1.10.2
* Mon Sep 19 2005 mmj@suse.de
- Fix strict aliasing issues
* Tue Aug 30 2005 mmj@suse.de
- Update to wget-1.10.1 which is a bugfix release [#113682]
* Mon Jun 13 2005 mmj@suse.de
- Update to wget-1.10 which has LFS and non-experimental IPv6,
  among many other improvements and bugfixes
* Tue Apr 26 2005 mmj@suse.de
- Fix the way fnmatch matches [#75791]
* Fri Apr  8 2005 mmj@suse.de
- Add sanitizing URLs patch
- Add other patches
* Thu Mar 31 2005 mmj@suse.de
- Don't double UTF-8 encode german messages [#74544]
* Fri Feb 11 2005 mmj@suse.de
- Roll back to wget-1.9.1 since the wget tree with LFS support is
  too buggy. We rather want a functioning wget. [#47965]
* Mon Jan 31 2005 ro@suse.de
- texi2html changed behaviour, adapt filelist
* Thu Dec  2 2004 mmj@suse.de
- Update to 20041113 wget-LFS snapshot
- Fix NULL pointer assertion [#48748]
* Mon Nov 15 2004 mmj@suse.de
- Use another version of the fix below
* Sun Nov 14 2004 mmj@suse.de
- Add fix for using proxies [#47965]
* Mon Oct 18 2004 mmj@suse.de
- locale no should correctly be nb so rename po/no* to po/nb*
* Mon Sep 27 2004 mmj@suse.de
- Use LFS patch from Leonid Petrov [#37967] [#45084]
* Mon Jun 28 2004 mmj@suse.de
- Fix what appears to be a copy/paste error in the dual-family
  IPv4+IPv6 patch [#42503].
* Thu Apr  1 2004 mmj@suse.de
- Enable download of files > 2 GB [#37967]
- Remove old crufty comments
* Fri Feb 20 2004 pth@suse.de
- Correctly set the charset for de.po to utf-8. Fixes #34708.
* Sun Feb  1 2004 mmj@suse.de
- Update to 1.9.1 which is a bugfix release
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Oct 28 2003 mmj@suse.de
- Add patch for dual-family IPv4+IPv6 support from Ari Edelkind
* Mon Oct 27 2003 mmj@suse.de
- Update to version 1.9 and remove patches, which was included
  upstream. 1.9 news:
  o specify what POST method be used for HTTP
  o IPv6 support is available, although it's still experimental
  o The `--timeout' option now also affects DNS lookup and
    establishing the TCP connection
  o Download speed shown by the progress bar is based on the data
    recently read, rather than the average speed of the entire
    download
  o It is now possible to connect to FTP servers through FWTK
    firewalls
  o The new option `--retry-connrefused' makes Wget retry
    downloads even in the face of refused connections
  o The new option `--dns-cache=off' may be used to prevent Wget
    from caching DNS lookups
  o Wget no longer escapes characters in local file names based
    on whether they're appropriate in URLs
  o Handling of HTML comments has been dumbed down to conform to
    what users expect and other browsers do: instead of being
    treated as SGML declaration, a comment is terminated at the
    first occurrence of "-->"
  o Wget now correctly handles relative URIs that begin with "//"
  o Boolean options in `.wgetrc' and on the command line now
    accept values "yes" and "no" along with the traditional "on"
    and "off"
  o It is now possible to specify decimal values for timeouts,
    waiting periods, and download rate.
* Tue Jul 15 2003 pthomas@suse.de
- Add security fix to unconditionally terminate the filename
  in url.c(compose_file_name).
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Tue Apr  1 2003 schwab@suse.de
- Define _GNU_SOURCE to fix missing declarations.
* Thu Mar  6 2003 ro@suse.de
- fix build with current autoconf
* Thu Mar  6 2003 pthomas@suse.de
- Add missing change log entry.
* Wed Mar  5 2003 pthomas@suse.de
- Add security fix that makes wget check for '..' and '/' in
  file names.
* Wed Feb 12 2003 kukuk@suse.de
- Remove ps and pdf documenation, info, man and html are enough.
  [Bug #23592]
* Tue Feb 11 2003 mmj@suse.de
- Use %%install_info macro [#23468]
- Don't remove $RPM_BUILD_ROOT without checking it's not "/"
* Thu Oct 24 2002 pthomas@suse.de
- Change wgetrc to make wget use passive_ftp per default.
* Wed Aug  7 2002 mmj@suse.de
- Update to 1.8.2 which is a bugfix release.
* Wed Jul 10 2002 okir@suse.de
- added patch for IPv6 support
* Tue May 14 2002 meissner@suse.de
- replaced assert msecs>=0 by if (msecs<0) msecs=0. (stupid assert)
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Jan 14 2002 bk@suse.de
- marked wgetrc as noreplace, format is compatible to older versions
* Mon Jan  7 2002 pthomas@suse.de
- Upgrade to 1.8.1
* Thu Dec 13 2001 pthomas@suse.de
- Upgrade to 1.8
- Regenerate pdf_doc.diff
- Drop ppc specific patch as it's not needed anymore.
- Install all HTML pages and not only the table of contents.
- Pass DESTDIR on from the toplevel Makefile.
* Mon Aug 20 2001 olh@suse.de
- add wget-1.7.ppc.diff to fix segfault on ppc
* Fri Jun  8 2001 pthomas@suse.de
- Upgrade to 1.7.
- Add a target to doc/Makefile to build a PDF version of the
  documentation.
- Compile with SSL support (for HTTPS).
* Fri May 25 2001 bjacke@suse.de
- apply and enable IPv6 patch
- add Debian's manpage
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Fri Mar 30 2001 pthomas@suse.de
- Apply my patch accepted for wget 1.7 that replaces ctype.h
  with safe-ctype.h, a locale independent version of ctype.h
  taken from libiberty. This makes setting LC_CTYPE safe.
* Thu Mar  8 2001 ke@suse.de
- Build and install a printable manual (PDF).
* Thu Mar  1 2001 pthomas@suse.de
- Set LC_CTYPE along with LC_MESSAGES to correctly display
  messages in locales other then C/POSIX.
* Wed Feb 14 2001 schwab@suse.de
- Fix large file support (#2647).
* Mon Jan 22 2001 ke@suse.de
- Update to version 1.6.
- wget.spec: Use proper rpm macros.
- Add README.SuSE
- Drop security patch (cf. 1999-02-09 and README.SuSE); not needed any
  longer.
- Lost large file support (cf. README.SuSE); reopen #2647.
* Fri Jun  9 2000 schwab@suse.de
- Change all values that count bytes from long to unsigned long (#2647).
* Sun Feb 20 2000 ke@suse.de
- General spec file cleanup:
- add group tag.
- use various macros (%%{version}, %%{_infodir}).
- ./configure -> %%build.
* Sat Oct  2 1999 ke@suse.de
- Add more PO files from
  http://www.iro.umontreal.ca/~pinard/po/HTML/domain-wget.html.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Feb  9 1999 ke@suse.de
- Security fix (proposed by marc).
* Sun Jan 17 1999 ke@suse.de
- apply patch (new de.po).
- fix BuildRoot.
* Thu Sep 24 1998 ke@suse.de
- Update: wget-1.5.3 (bug fix release).
* Fri Jun 26 1998 ke@suse.de
- Update: wget-1.5.2 (bug fix release).
- Make BuildRoot work.
* Tue May 12 1998 ke@suse.de
- update: wget-1.5.1 (bug fix release).
* Fri Apr 24 1998 ke@suse.de
- enable NLS.
* Thu Apr 23 1998 ke@suse.de
- update: wget-1.5.0.
* Sat Jun 21 1997 Karl Eichwalder  <ke@suse.de>
  * patch from Hrvoje Niksic to prevent crashes if you are using
  proxy authorization.
* Mon May 19 1997 Karl Eichwalder  <ke@suse.de>
  * new package: wget-1.4.5
